@@ -11,25 +11,25 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
     $|++;
 
     sub configure {
-        my ($self) = @_;
+        my ($self, @args) = @_;
         $self->quiet(1);
-        $self->SUPER::configure();
-        $self->notes(ldflags => $self->notes('ldflags')
-                 . ' -mwindows -lmsimg32 -lole32 -luuid -lcomctl32 -lwsock32 '
-        );
+        $self->SUPER::configure()
+            if !grep {m[no_base]} @args;    # Get basic config data
+        $self->notes(  ldflags => ' -mwindows '
+                     . $self->notes('ldflags')
+                     . ' -lmsimg32 -lole32 -luuid -lcomctl32 -lwsock32');
+        $self->notes('cxxflags' => '-mwindows -DWIN32 -Wno-non-virtual-dtor '
+                     . $self->notes('cxxflags'));
         $self->notes(
-              'cxxflags' => ' -mwindows -DWIN32 ' . $self->notes('cxxflags'));
-        $self->notes('define')->{'HAVE_STRCASECMP'}    = undef;
-        $self->notes('define')->{'HAVE_STRNCASECMP'}   = undef;
-        $self->notes('define')->{'HAVE_STRNCASECMP'}   = undef;
-        $self->notes('define')->{'HAVE_DIRENT_H'}      = undef;
-        $self->notes('define')->{'HAVE_SYS_NDIR_H'}    = undef;
-        $self->notes('define')->{'HAVE_SYS_DIR_H'}     = undef;
-        $self->notes('define')->{'HAVE_NDIR_H'}        = undef;
-        $self->notes('define')->{'HAVE_SCANDIR'}       = undef;
-        $self->notes('define')->{'HAVE_SCANDIR_POSIX'} = undef;
+                   'cflags' => '-mwindows -DWIN32 ' . $self->notes('cflags'));
+
+        #$self->notes('define')->{'HAVE_DIRENT_H'}   = undef;
+        #$self->notes('define')->{'HAVE_SYS_NDIR_H'} = undef;
+        #$self->notes('define')->{'HAVE_SYS_DIR_H'}  = undef;
+        #$self->notes('define')->{'HAVE_NDIR_H'}     = undef;
+        $self->notes('define')->{'HAVE_SCANDIR'} = undef;
     GL: {
-            last GL if !$self->find_h('GL/gl.h');
+            last if grep {m[^no_gl$]} @args;
             print 'Testing GL Support... ';
             if (!$self->assert_lib({lib => 'opengl32', header => 'GL/gl.h'}))
             {   print "not okay\n";
@@ -38,6 +38,11 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
                                message => 'OpenGL libs were not found'
                               }
                 );
+                $self->notes(GL => '');
+                for my $lib (keys %{$self->notes('libs_source')}) {
+                    $self->notes('libs_source')->{$lib}{'disabled'}++
+                        if $lib =~ m[gl]i;
+                }
                 last GL;
             }
             print "okay\n";
@@ -52,6 +57,11 @@ package inc::MBX::Alien::FLTK::Platform::Windows;
                                message => 'OpenGLU32 libs were not found'
                               }
                 );
+                $self->notes(GL => '');
+                for my $lib (keys %{$self->notes('libs_source')}) {
+                    $self->notes('libs_source')->{$lib}{'disabled'}++
+                        if $lib =~ m[gl]i;
+                }
                 last GL;
             }
             else {
