@@ -3,11 +3,11 @@ package Alien::FLTK2;
     use strict;
     use warnings;
     use File::Spec::Functions qw[catdir rel2abs canonpath];
-    our $BASE = 0; our $SVN = 6970; our $DEV = 14; our $VERSION = sprintf('%d.%05d' . ($DEV ? '_%03d' : ''), $BASE, $SVN, $DEV);
+    our $BASE = 0; our $SVN = 7680; our $DEV = 1; our $VERSION = sprintf('%d.%05d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%03d') : ('')), $BASE, $SVN, abs $DEV);
 
     sub _md5 {
-        return {gz  => '8159cabebbd1b5b774b277827aa4e030',
-                bz2 => 'f78976d0ba1a5c845e14f4df96d580a0'
+        return {gz  => '6d3ea46a7392bccbcd96b6c6d569446f',
+                bz2 => '677cfe42553355bdc21d79722687c1b0'
         };
     }
     sub _unique_file { return 'src/Widget.cxx' }
@@ -20,8 +20,8 @@ package Alien::FLTK2;
             ($self->{'basedir'})
                 = (grep { -d $_ && -f catdir($_, 'config.yml') }
                        map { rel2abs($_) } (
-                             eval { File::ShareDir::dist_dir('Alien-FLTK2') },
-                             'share', '../share', '../../share'
+                        'share', '../share', '../../share',
+                        eval { File::ShareDir::dist_dir('Alien-FLTK2') }
                        )
                 );
         }
@@ -61,19 +61,20 @@ package Alien::FLTK2;
 
     sub ldflags {    # XXX - Cache this
         my ($self, @args) = @_;
+        my $MSVC = 'Windows|MSVC' eq join '|', @{$self->config->{'platform'}};
 
         #
         my $libdir = shift->library_path();
 
         # Calculate needed libraries
         my $SHAREDSUFFIX
-            = $self->config->{'_a'} ? $self->config->{'_a'}
-            : $^O =~ '$MSWin32' ? '.a'
+            = $self->config->{'_a'}
+            ? $self->config->{'_a'}
+            : $^O =~ '$MSWin32' ? '.a'    # Even on MSVC... for now.
             :                     '.o';
-        my $LDSTATIC = sprintf '-L%s %s/libfltk2%s %s', $libdir, $libdir,
-            $SHAREDSUFFIX,
+        my $LDSTATIC = sprintf '%s/libfltk2%s %s', $libdir, $SHAREDSUFFIX,
             ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
-        my $LDFLAGS = "-L$libdir -lfltk2 "
+        my $LDFLAGS = '-lfltk2 '
             . ($self->config->{'ldflags'} ? $self->config->{'ldflags'} : '');
         my $LIBS = sprintf '%s/libfltk2%s', $libdir, $SHAREDSUFFIX;
         if (grep {m[forms]} @args) {
@@ -98,8 +99,16 @@ package Alien::FLTK2;
             $LDSTATIC = sprintf '%s/libfltk2_images%s %s %s',
                 $libdir, $SHAREDSUFFIX, $img_libs, $LDSTATIC;
         }
-        return (
-             ((grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS) . ' -lsupc++');
+        my $ret
+            = (  " -L$libdir "
+               . (($MSVC || grep {m[static]} @args) ? $LDSTATIC : $LDFLAGS)
+               . ($MSVC ? '' : ' -lsupc++'));
+        if ($MSVC) {    # Oy...
+            $ret =~ s[-L([^\s]*)][/libpath:"$1"]g;
+            $ret =~ s[-l([^\s]*)][$1]g;
+            $ret =~ s[-D([^\s]+)][/D"$1"]g;
+        }
+        return $ret;
     }
 
     sub capabilities {
@@ -117,7 +126,7 @@ package Alien::FLTK2;
 
 =head1 NAME
 
-Alien::FLTK2 - Build and use the Fast Light Toolkit binaries
+Alien::FLTK2 - Build and use the experimental 2.0.x branch Fast Light Toolkit
 
 =head1 Description
 
@@ -213,8 +222,8 @@ arguments are:
 
 Returns flags to link against a static FLTK library.
 
-FLTK's license allows static linking, but L<Alien::FLTK2|Alien::FLTK2> does not
-build static libs. ...yet.
+FLTK's license allows static linking, but L<Alien::FLTK2|Alien::FLTK2> does
+not build static libs. ...yet.
 
 =item C<gl>
 
@@ -280,17 +289,20 @@ Prerequisites differ by system...
 
 =item Win32
 
-The fltk2 libs and L<Alien::FLTK2|Alien::FLTK2> both build right out of the box
-with MinGW. Further testing is needed for other setups.
+The fltk2 libs and L<Alien::FLTK2|Alien::FLTK2> both build right out of the
+box with MinGW. Further testing is needed for other setups.
 
 =item X11/*nix
 
 X11-based systems require several development packages. On Debian, these may
-be installed with...
+be installed with:
 
-  > sudo apt-get install libx11-dev
-  > sudo apt-get install libxi-dev
-  > sudo apt-get install libxcursor-dev
+    > sudo apt-get install libx11-dev
+    > sudo apt-get install libxi-dev
+
+Additionally, the optional XCurser lib may be installed with:
+
+    > sudo apt-get install libxcursor-dev
 
 =item Darwin/OSX
 
@@ -317,7 +329,7 @@ following procedure:
 http://github.com/sanko/alien-fltk/issues
 
 Please only report L<Alien::FLTK2|Alien::FLTK2> related bugs to this tracker.
-For L<FLTK|FLTK> issues, use http://github.com/sanko/fltk-perl/issues/
+For L<FLTK|FLTK> issues, use http://github.com/sanko/fltk-perl2/issues/
 
 =item * Commit Log
 
@@ -341,13 +353,13 @@ for L<Alien::FLTK2|Alien::FLTK2> too.
 
 =item * Repository
 
-http://github.com/sanko/alien-fltk/ and you are invited to fork it.
+http://github.com/sanko/alien-fltk2/ and you are invited to fork it.
 
 =back
 
 =head2 Examples
 
-Please see the L<Synopsis|/"Synopsis"> and the files in the C</examples/>.
+Please see the L<Synopsis|Alien::FLTK2/"Synopsis"> and the files in the C</examples/>.
 
 =head2 Bugs
 
@@ -392,6 +404,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 L<Alien::FLTK2|Alien::FLTK2> is based in part on the work of the FLTK project.
 See http://www.fltk.org/.
 
-=for git $Id: FLTK2.pm c1838b2 2010-01-27 20:29:32Z sanko@cpan.org $
+=for git $Id: FLTK2.pm 4c1b0cc 2010-09-07 04:05:07Z sanko@cpan.org $
 
 =cut
